import { objectWithoutProperties as _objectWithoutProperties, extends as _extends } from '../../_virtual/_rollupPluginBabelHelpers.js';
import React, { forwardRef } from 'react';
import { component, mergeConfig, textFieldConfig } from '@salutejs/plasma-new-hope';
import { config } from './TextField.config.js';

var _excluded = ["view", "status", "label", "caption", "placeholder", "helperText", "enumerationType", "chips", "onSearch", "onChangeChips"];
var mergedConfig = /*#__PURE__*/mergeConfig(textFieldConfig, config);
var TextFieldComponent = /*#__PURE__*/component(mergedConfig);
var statusToView = {
  success: 'positive',
  warning: 'warning',
  error: 'negative'
};
var viewToLabelPlacement = {
  "default": 'outer',
  innerLabel: 'inner'
};

/**
 * Поле ввода текста.
 */
var TextField = /*#__PURE__*/forwardRef(function (props, ref) {
  var view = props.view,
    status = props.status,
    label = props.label,
    caption = props.caption,
    placeholder = props.placeholder,
    helperText = props.helperText,
    enumerationType = props.enumerationType,
    chips = props.chips,
    onSearch = props.onSearch,
    onChangeChips = props.onChangeChips,
    rest = _objectWithoutProperties(props, _excluded);

  /** TODO: https://github.com/salute-developers/plasma/issues/1064 Remove In plasma-2.0 */
  /* eslint-disable no-underscore-dangle */
  var _view = status ? statusToView[status] : 'default';
  var _labelPlacement = view ? viewToLabelPlacement[view] : 'outer';
  var _label = label ? String(label) : caption;
  var _placeholder = placeholder;
  // NOTE: rest.size https://github.com/salute-developers/plasma/issues/961
  // if size is undefined <TextFieldComp size={size} /> would not use defaults
  if (rest.size === 'xs' && _labelPlacement === 'inner') {
    _placeholder = _label;
    _label = undefined;
    _labelPlacement = 'outer';
  }
  if (enumerationType === 'chip') {
    return /*#__PURE__*/React.createElement(TextFieldComponent, _extends({}, rest, {
      view: _view,
      labelPlacement: _labelPlacement,
      label: _label,
      placeholder: _placeholder,
      leftHelper: helperText,
      ref: ref,
      enumerationType: "chip",
      chips: chips,
      onChangeChips: onChangeChips
    }));
  }
  return /*#__PURE__*/React.createElement(TextFieldComponent, _extends({}, rest, {
    view: _view,
    labelPlacement: _labelPlacement,
    label: _label,
    placeholder: _placeholder,
    leftHelper: helperText,
    ref: ref,
    enumerationType: "plain",
    onSearch: onSearch
  }));
});

export { TextField };
//# sourceMappingURL=TextField.js.map
